@@ -1,69 +1,79 @@
- depth.RPD<-function (fdataobj, nproj = 50, proj=1,deriv = c(0, 1), trim = 0.25,
+
+ depth.RPD<-function (fdataobj,fdataori=fdataobj, nproj = 50, proj=1,deriv = c(0, 1), trim = 0.25,
     dfunc2 = depth.mode, method = "fmm", draw = FALSE, ...)
 {
-    if (!is.fdata(fdataobj))
-        fdataobj = fdata(fdataobj)
+    if (!is.fdata(fdataobj))         fdataobj = fdata(fdataobj)
+    if (!is.fdata(fdataori)) fdataobj=fdata(fdataori)    
     nas <- apply(fdataobj$data, 1, count.na)
     if (any(nas)) {
         fdataobj$data <- fdataobj$data[!nas, ]
         cat("Warning: ", sum(nas), " curves with NA are not used in the calculations \n")
     }
     data <- fdataobj[["data"]]
+    data2 <- fdataori[["data"]]    
     names1 <- names2 <- names <- fdataobj[["names"]]
     names1$main <- "depth.RPD median"
     names2$main <- paste("RPD trim ", trim * 100, "%", sep = "")
     n <- nrow(data)
     m <- ncol(data)
+    m2<-ncol(data2)
+    n2<-nrow(data2)    
+    if (is.null(m) && is.null(m2)) stop("ERROR IN THE DATA DIMENSIONS")
     modulo = function(z) {        sqrt(sum(z^2))    }
-    if (is.null(n) || is.null(m))
-        stop("Input must be a matrix")
+    if (is.null(n) || is.null(m))       stop("Input must be a matrix")
     tt = fdataobj[["argvals"]]
     rtt <- fdataobj[["rangeval"]]
     newfunc = array(NA, dim = c(n, m, length(deriv)))
+    newfunc2 = array(NA, dim = c(n2, m2, length(deriv)))    
     for (ider in 1:length(deriv)) {
-        if (deriv[ider] == 0) {
-            newfunc[, , ider] = data
-        }
+        if (deriv[ider] == 0) {   
+          newfunc[, , ider] = data     
+          newfunc2[, , ider] = data     
+          } 
         else {
-            newfunc[, , ider] = fdata.deriv(data, nderiv = (ider -
+            newfunc[, , ider] = fdata.deriv(fdataobj, nderiv = (ider -
                 1), method = method, ...)[["data"]]
+            newfunc2[, , ider] = fdata.deriv(fdataori, nderiv = (ider -
+                1), method = method, ...)[["data"]]               
         }
     }
     dep = rep(0, n)
     vproject = matrix(0, nrow = n, ncol = length(deriv))
+    vproject2 = matrix(0, nrow = n2, ncol = length(deriv))    
     z = rnorm(m * nproj)
     z = matrix(z, nrow = nproj, ncol = m)
     modu = apply(z, 1, modulo)
     z = z/modu
-if (is.fdata(proj)) {
-  if (fdataobj$argvals!=proj$argvals || ncol(fdataobj)!=ncol(proj)) stop("Error en proj dimension")
-  z<-proj
-  }
-else {
-	z<-rproc2fdata(nproj,tt,sigma=proj,norm=TRUE,...)
-	}
-    pb = txtProgressBar(min = 0, max = nproj, style = 3)
-    for (j in 1:nproj) {
+    if (is.fdata(proj)) {
+     if (fdataobj$argvals!=proj$argvals || ncol(fdataobj)!=ncol(proj)) stop("Error en proj dimension")
+     z<-proj
+     nproj<-nrow(z)
+    }
+  else {	 z<-rproc2fdata(nproj,tt,sigma=proj,norm=TRUE,...)	}
+  pb = txtProgressBar(min = 0, max = nproj, style = 3)
+  for (j in 1:nproj) {
         setTxtProgressBar(pb, j - 0.5)
         for (ider in 1:length(deriv)) {
             matriz = newfunc[, , ider]
-            vproject[, ider] = matriz %*%z$data[j, ] #**
+            vproject[, ider] = matriz %*%z$data[j, ]
+            vproject2[, ider] = newfunc2[, , ider] %*%z$data[j, ]              
         }
-        resul = dfunc2(vproject, ...)
+#        resul = dfunc2(vproject, ...)       
         par.dfunc = list()
-        par.dfunc$fdataobj <- vproject
-        par.dfunc$trim <- trim
+        par.dfunc$fdataobj <- fdata(vproject)
+        par.dfunc$fdataori <- fdata(vproject2    )
+        par.dfunc$trim <- trim              
+        par.dfunc$scale<-TRUE
         resul = do.call(dfunc2, par.dfunc)
         dep = dep + resul$dep
         setTxtProgressBar(pb, j)
-    }
+    } 
     close(pb)
     dep = dep/nproj
     k = which.max(dep)
     med = data[k, ]
     lista = which(dep >= quantile(dep, probs = trim))
-#    mtrim = apply(data[lista, ], 2, mean, na.rm = TRUE)
-    mtrim = colMeans(data[lista, ], na.rm = TRUE)
+    mtrim = apply(data[lista, ], 2, mean, na.rm = TRUE)
     tr <- paste("RPD.tr", trim * 100, "%", sep = "")
     med <- fdata(med, tt, rtt, names1)
     mtrim <- fdata(mtrim, tt, rtt, names2)
@@ -78,10 +88,9 @@ else {
         plot(fdataobj[ind1, ], col = gray(cgray[ind1]), main = "RPD Depth")
         lines(mtrim, lwd = 2, col = "yellow")
         lines(med, col = "red", lwd = 2)
-        legend("topleft", legend = c(tr, "Median"), lwd = 2,
+        legend("topleft", legend = c(tr, "Median"), lwd = 2,box.col=0,
             col = c("yellow", "red"))
     }
     return(invisible(list(median = med, lmed = k, mtrim = mtrim,
         ltrim = lista, dep = dep, proj = z)))
-}
-
+}  
