@@ -8,13 +8,22 @@ rtt<-fdataobj[["rangeval"]]
 n<-nrow(fdataobj)
 m<-ncol(fdataobj)
 if (is.null(n) && is.null(m)) stop("ERROR IN THE DATA DIMENSIONS")
+scale=FALSE
 cutoff<-median(quantile.outliers.pond(x,dfunc=dfunc,nb=nb,smo=smo,...))
     hay<-1
     outliers<-c();dep.out<-c()
     curvasgood<-fdataobj
     row.names(curvasgood[["data"]])=1:n
+    dd<-dfunc(curvasgood,...)     
+    modal<-FALSE
+    if (!is.null(dd$dist)) {
+      modal=TRUE   
+      dd<-dfunc(curvasgood,...)
+          }
+    d<-dd$dep 
+    
     while (hay==1){
-          d=dfunc(curvasgood,...)$dep
+#          d=dfunc(curvasgood,...)$dep
           if (is.null(outliers)){dtotal<-d}
           fecha<-as.numeric(row.names(curvasgood[["data"]])[d<cutoff])
           elim<-which(d<cutoff)
@@ -24,10 +33,19 @@ cutoff<-median(quantile.outliers.pond(x,dfunc=dfunc,nb=nb,smo=smo,...))
              outliers<-c(outliers,fecha)
           }
         if (length(elim)==0 || length(outliers)>n/5){hay<-0}
+                else {
+            if (modal) {
+             mdist<-dd$dist[-elim,-elim]
+            class(mdist)<-c("matrix","fdist")        
+            dd<-dfunc(curvasgood,metric=mdist,...)
+            }
+          else dd<-dfunc(curvasgood,...)
+          d<-dd$dep 
+          }
     }
+outliers<-rownames(fdataobj[["data"]])[outliers]    
 return(list("outliers"=outliers,"quantile"=cutoff,"dep"=dtotal,"dep.out"=dep.out))
 c(outliers,cutoff,dtotal,dep.out)
 }
 
-
-
+ 
\ No newline at end of file
