@@ -1,6 +1,9 @@
 predict.classif<-function(object,new.fdataobj=NULL,type="class",...)
 {
-    lev<-levels(object$group)
+    if (is.null(new.fdataobj)) return(object$group.est)
+    isfdata<-is.fdata(new.fdataobj)
+    object$group<-factor(object$group,levels=levels(object$group)[which(table(object$group)>0)])
+    ny<-lev<-levels(object$group)
 #    if (is.null(object)) stop("No classif object entered")
 #    if (is.null(new.fdataobj)) stop("No newx entered")
     if (object$C[[1]] == "classif.tree"|object$C[[1]] == "classif.tree2boost") {
@@ -257,9 +260,9 @@ predict.classif<-function(object,new.fdataobj=NULL,type="class",...)
     }
 
 if (object$C[[1]] == "classif.np") {
-    
-if (!is.fdata(new.fdataobj)) new.fdataobj=fdata(new.fdataobj,object$fdataobj[["argvals"]],object$fdataobj[["rangeval"]],object$fdataobj[["names"]])
+#if (!is.fdata(new.fdataobj)) new.fdataobj=fdata(new.fdataobj,object$fdataobj[["argvals"]],object$fdataobj[["rangeval"]],object$fdataobj[["names"]])
 gg<-1:nrow(new.fdataobj)
+if (isfdata) {
 nas<-apply(new.fdataobj$data,1,count.na)
 if (any(nas)) {
    bb<-!nas
@@ -267,15 +270,18 @@ if (any(nas)) {
    new.fdataobj$data<-new.fdataobj$data[bb,]
    gg<-gg[bb]
    }
-newx<-new.fdataobj[["data"]]
-tt<-new.fdataobj[["argvals"]]
-rtt<-new.fdataobj[["rangeval"]]
+  newx<-new.fdataobj[["data"]]
+  tt<-new.fdataobj[["argvals"]]
+  rtt<-new.fdataobj[["rangeval"]]
+}
+else newx<-new.fdataobj
 nn <- nrow(new.fdataobj)
  if (is.null(rownames(newx)))         rownames(newx) <- 1:nn
 # if (is.vector(newx))  newx <- t(as.matrix(newx))
  x=object$fdataobj
  y=object$y
- h=object$h.opt
+  h=object$h.opt
+# h<-0.5
  n = nrow(x)
  nn = nrow(newx)
  np <- ncol(x)
@@ -289,40 +295,41 @@ nn <- nrow(new.fdataobj)
  Ker=object$Ker
    par.metric<-list()
    par.metric<-attr(object$mdist,"par.metric")
+   parm<-attr(object$mdist,"par.metric")
+   a1<-attr(object$mdist,"call")
+if (isfdata) {   
    par.metric[["fdata2"]]<-x
    par.metric[["fdata1"]]<-new.fdataobj
-   parm<-attr(object$mdist,"par.metric")
-#   par.metric[3:(2+length(parm))]<-attr(object$mdist,"par.metric")
-#   print(attr(object$mdist,"par.metric"))
-#   print(names(attr(object$mdist,"par.metric")[3:(2+length(parm))]))
-#   names(par.metric[3:(2+length(parm))])<-names(attr(object$mdist,"par.metric"))
-#   print(names(par.metric))
-   a1<-attr(object$mdist,"call")
-   nmdist <- do.call(a1,par.metric)
-#   metric.lp(newx,x,...)
+   nmdist <- do.call(a1,par.metric)   
+   }
+else {
 
-#   if (ty=="S.KNN") object$Ker<-Ker.unif
+   par.metric[["x"]]<-new.fdataobj
+   par.metric[["y"]]<-x
+   nmdist <- do.call(a1,par.metric)
+  }
+#  print(nmdist)   
    object$par.S$cv=FALSE
    object$par.S$tt<-nmdist
-   kmdist=object$type.S(nmdist,h=h, Ker=object$Ker, cv = FALSE)
-  #   kmdist=do.call(ty,object$par.S)
-# yp=kmdist%*%matrix(y,ncol=1)
-        pgrup = array(0, dim = c(numg, nn))
+   kmdist=object$type.S(nmdist,h=h,Ker=object$Ker, cv = FALSE)
+         pgrup = array(0, dim = c(numg, nn))
         l = array(0, dim = c(nn))
         group.pred = array(0, dim = nn)
         for (j in 1:numg) {
-            grup = as.integer(y == ny[j])
+            grup = as.integer(y == lev[j])  
             pgrup[j, ] <- kmdist%*%matrix(grup,ncol=1)
-        }
-    group.pred<-factor(ny[apply(pgrup,2,which.max)],levels=ny)
+        }  
+#    group.pred<-factor(ny[apply(pgrup,2,which.max)],levels=ny)
+    group.pred<-factor(ifelse(apply(pgrup,2,which.max)==1,lev[1],lev[2])   ) 
 #return(group.pred)
 }
 #    group.pred=factor(group.pred,levels=lev)
+
 if (type=="class")   return(group.pred)
 else {
-        colnames(pgrup) <- rownames(new.fdataobj$data)
+    if (isfdata)          colnames(pgrup) <- rownames(new.fdataobj$data)
+    else           colnames(pgrup) <- rownames(new.fdataobj)
         rownames(pgrup) <- levels(object$group)
         return(list(group.pred = group.pred, prob.group = pgrup))
     }
 }
-
